window.Gleam.initSearch([{"doc":"glats","title":"glats","content":"# glats\n\n[![Package Version](https://img.shields.io/hexpm/v/glats)](https://hex.pm/packages/glats)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glats/)\n\nA NATS client for Gleam. This wraps Elixir&#39;s client, [Gnat](https://hex.pm/packages/gnat).\n\n## Publish\n\n```gleam\nimport gleam/result\nimport glats\nimport glats/settings\n\npub fn main() {\n  use conn &lt;- result.then(\n    settings.new(&quot;localhost&quot;, 4222)\n    |&gt; glats.connect,\n  )\n\n  // Publish a single message to &quot;some.subject&quot;.\n  assert Ok(Nil) = glats.publish(conn, &quot;some.subject&quot;, &quot;hello world!&quot;)\n\n  Ok(Nil)\n}\n```\n\n## Subscribe\n\n```gleam\nimport gleam/io\nimport gleam/result\nimport gleam/erlang/process\nimport glats\nimport glats/settings\n\npub fn main() {\n  use conn &lt;- result.then(\n    settings.new(&quot;localhost&quot;, 4222)\n    |&gt; glats.connect,\n  )\n\n  let subject = process.new_subject()\n\n  // Subscribe to &quot;some.subject&quot;.\n  // Messages will be delivered to the erlang subject passed in.\n  assert Ok(sid) = glats.subscribe(conn, subject, &quot;some.subject&quot;)\n\n  // Publish a single message to &quot;some.subject&quot;.\n  assert Ok(Nil) = glats.publish(conn, &quot;some.subject&quot;, &quot;hello world!&quot;)\n\n  // Receive from erlang subject.\n  assert Ok(msg) = process.receive(subject, 1000)\n\n  // Prints: `Message(&quot;some.subject&quot;, //erl(#{}), None, &quot;hello world!&quot;)`.\n  io.debug(msg)\n\n  // Unsubscribe from the subscription.\n  assert Ok(Nil) = glats.unsubscribe(conn, sid)\n\n  Ok(Nil)\n}\n```\n\n## Installation\n\n```sh\ngleam add glats\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/glats&gt;.\n","url":"index.html"},{"doc":"glats/settings","title":"Settings","content":"pub type Settings {\n  Settings(\n    host: Option(String),\n    port: Option(Int),\n    tls: Option(Bool),\n    ssl_opts: Option(Map(String, String)),\n  )\n}\n Connection settings for NATS connection.\nSettings(\n  host: Option(String),\n  port: Option(Int),\n  tls: Option(Bool),\n  ssl_opts: Option(Map(String, String)),\n)\n\n\nSynonyms:\nglats/settings.Settings\nglats/settings Settings","url":"glats/settings.html#Settings"},{"doc":"glats/settings","title":"defaults","content":"pub fn defaults() -&gt; Settings\n Returns settings with `localhost:4222`.\n\n Use builder functions `set_*` to add additional options.\n\n \n defaults()\n |&gt; set_port(6222)\n |&gt; set_ca(&quot;/tmp/ca.crt&quot;)\n \nSynonyms:\nglats/settings.defaults\nglats/settings defaults","url":"glats/settings.html#defaults"},{"doc":"glats/settings","title":"new","content":"pub fn new(host: String, port: Int) -&gt; Settings\n Creates a settings with `host` and `port` set.\n\n Use builder functions `set_*` to add additional options.\n\n \n new(&quot;localhost&quot;, 4222)\n |&gt; set_ca(&quot;/tmp/ca.crt&quot;)\n \nSynonyms:\nglats/settings.new\nglats/settings new","url":"glats/settings.html#new"},{"doc":"glats/settings","title":"set_ca","content":"pub fn set_ca(settings: Settings, cafile: String) -&gt; Settings\n Sets the CA file to use in connection settings.\nSynonyms:\nglats/settings.set_ca\nglats/settings set_ca","url":"glats/settings.html#set_ca"},{"doc":"glats/settings","title":"set_client_cert","content":"pub fn set_client_cert(settings: Settings, certfile: String, keyfile: String) -&gt; Settings\n Sets client certificates in connection settings.\nSynonyms:\nglats/settings.set_client_cert\nglats/settings set_client_cert","url":"glats/settings.html#set_client_cert"},{"doc":"glats/settings","title":"set_host","content":"pub fn set_host(settings: Settings, host: String) -&gt; Settings\n Sets the host for connection settings.\nSynonyms:\nglats/settings.set_host\nglats/settings set_host","url":"glats/settings.html#set_host"},{"doc":"glats/settings","title":"set_no_tls","content":"pub fn set_no_tls(settings: Settings) -&gt; Settings\n Explicitly disables tls and resets ssl_opts for the connection settings.\nSynonyms:\nglats/settings.set_no_tls\nglats/settings set_no_tls","url":"glats/settings.html#set_no_tls"},{"doc":"glats/settings","title":"set_port","content":"pub fn set_port(settings: Settings, port: Int) -&gt; Settings\n Sets the port for connection settings.\nSynonyms:\nglats/settings.set_port\nglats/settings set_port","url":"glats/settings.html#set_port"},{"doc":"glats/settings","title":"glats/settings","content":"","url":"glats/settings.html"},{"doc":"glats/message","title":"Message","content":"pub type Message {\n  Message(\n    subject: String,\n    headers: Map(String, String),\n    reply_to: Option(String),\n    body: String,\n  )\n}\n A single message that can be received from or sent to NATS.\nMessage(\n  subject: String,\n  headers: Map(String, String),\n  reply_to: Option(String),\n  body: String,\n)\n\n\nSynonyms:\nglats/message.Message\nglats/message Message","url":"glats/message.html#Message"},{"doc":"glats/message","title":"new","content":"pub fn new(subject: String, body: String) -&gt; Message\n Constructs a new message.\nSynonyms:\nglats/message.new\nglats/message new","url":"glats/message.html#new"},{"doc":"glats/message","title":"set_header","content":"pub fn set_header(message: Message, key: String, value: String) -&gt; Message\n Sets a header in a message.\nSynonyms:\nglats/message.set_header\nglats/message set_header","url":"glats/message.html#set_header"},{"doc":"glats/message","title":"set_reply_to","content":"pub fn set_reply_to(message: Message, reply_to: String) -&gt; Message\n Sets the reply_to subject of a message.\nSynonyms:\nglats/message.set_reply_to\nglats/message set_reply_to","url":"glats/message.html#set_reply_to"},{"doc":"glats/message","title":"glats/message","content":"","url":"glats/message.html"},{"doc":"glats/protocol","title":"ServerInfo","content":"pub type ServerInfo {\n  ServerInfo(\n    server_id: String,\n    server_name: String,\n    version: String,\n    go: String,\n    host: String,\n    port: Int,\n    headers: Bool,\n    max_payload: Int,\n    proto: Int,\n    jetstream: Bool,\n    auth_required: Option(Bool),\n  )\n}\n Server info returned by the NATS server.\nServerInfo(\n  server_id: String,\n  server_name: String,\n  version: String,\n  go: String,\n  host: String,\n  port: Int,\n  headers: Bool,\n  max_payload: Int,\n  proto: Int,\n  jetstream: Bool,\n  auth_required: Option(Bool),\n)\n\n\nSynonyms:\nglats/protocol.ServerInfo\nglats/protocol ServerInfo","url":"glats/protocol.html#ServerInfo"},{"doc":"glats/protocol","title":"glats/protocol","content":"","url":"glats/protocol.html"},{"doc":"glats","title":"Connection","content":"pub type Connection =\n  Subject(ConnectionMessage)\n\n\nSynonyms:\nglats.Connection\nglats Connection","url":"glats.html#Connection"},{"doc":"glats","title":"ConnectionError","content":"pub type ConnectionError {\n  Timeout\n  NoResponders\n  Unexpected\n}\n Errors that can be returned by the server.\n\nTimeout\n\n\nNoResponders\n\n\nUnexpected\n\n\nSynonyms:\nglats.ConnectionError\nglats ConnectionError","url":"glats.html#ConnectionError"},{"doc":"glats","title":"ConnectionMessage","content":"pub opaque type ConnectionMessage\n Message sent to a NATS connection process.\n\nSynonyms:\nglats.ConnectionMessage\nglats ConnectionMessage","url":"glats.html#ConnectionMessage"},{"doc":"glats","title":"active_subscriptions","content":"pub fn active_subscriptions(conn: Subject(ConnectionMessage)) -&gt; Result(\n  Int,\n  ConnectionError,\n)\n Returns the number of active subscriptions for the connection.\n\nSynonyms:\nglats.active_subscriptions\nglats active_subscriptions","url":"glats.html#active_subscriptions"},{"doc":"glats","title":"connect","content":"pub fn connect(settings: Settings) -&gt; Result(\n  Subject(ConnectionMessage),\n  StartError,\n)\n Starts an actor that handles a connection to NATS using the provided\n settings.\n\nSynonyms:\nglats.connect\nglats connect","url":"glats.html#connect"},{"doc":"glats","title":"publish","content":"pub fn publish(conn: Subject(ConnectionMessage), subject: String, message: String) -&gt; Result(\n  Nil,\n  String,\n)\n Publishes a single message to NATS on a provided subject.\n\nSynonyms:\nglats.publish\nglats publish","url":"glats.html#publish"},{"doc":"glats","title":"publish_message","content":"pub fn publish_message(conn: Subject(ConnectionMessage), message: Message) -&gt; Result(\n  Nil,\n  String,\n)\n Publishes a single message to NATS using the data from a provided `Message`\n record.\n\nSynonyms:\nglats.publish_message\nglats publish_message","url":"glats.html#publish_message"},{"doc":"glats","title":"queue_subscribe","content":"pub fn queue_subscribe(conn: Subject(ConnectionMessage), subscriber: Subject(\n    Message,\n  ), subject: String, group: String) -&gt; Result(Int, String)\n Subscribes to a NATS subject as part of a queue group.\n Messages can be received on the provided OTP subject.\n\n See [Queue Groups docs.](https://docs.nats.io/nats-concepts/core-nats/queue)\n\nSynonyms:\nglats.queue_subscribe\nglats queue_subscribe","url":"glats.html#queue_subscribe"},{"doc":"glats","title":"request","content":"pub fn request(conn: Subject(ConnectionMessage), subject: String, message: String) -&gt; Result(\n  Message,\n  ConnectionError,\n)\n Sends a request and listens for a response synchronously.\n\n See [request-reply pattern docs.](https://docs.nats.io/nats-concepts/core-nats/reqreply)\n\nSynonyms:\nglats.request\nglats request","url":"glats.html#request"},{"doc":"glats","title":"server_info","content":"pub fn server_info(conn: Subject(ConnectionMessage)) -&gt; Result(\n  ServerInfo,\n  ConnectionError,\n)\n Returns server info provided by the connected NATS server.\n\nSynonyms:\nglats.server_info\nglats server_info","url":"glats.html#server_info"},{"doc":"glats","title":"subscribe","content":"pub fn subscribe(conn: Subject(ConnectionMessage), subscriber: Subject(\n    Message,\n  ), subject: String) -&gt; Result(Int, String)\n Subscribes to a NATS subject that can be received on the\n provided OTP subject.\n\nSynonyms:\nglats.subscribe\nglats subscribe","url":"glats.html#subscribe"},{"doc":"glats","title":"unsubscribe","content":"pub fn unsubscribe(conn: Subject(ConnectionMessage), sid: Int) -&gt; Result(\n  Nil,\n  String,\n)\n Unsubscribe from a subscription by providing the subscription ID.\n\nSynonyms:\nglats.unsubscribe\nglats unsubscribe","url":"glats.html#unsubscribe"},{"doc":"glats","title":"glats","content":"","url":"glats.html"}]);